@@ -216,9 +216,17 @@ sub print_end_statistics {
     
     my $num_man_pages = shift;
     my $index_file = shift;
+    my $duplicate = shift;
+    my $link = shift;
+    my $empty = shift;
+    my $true_man_pages = shift;
     my $occurrence_get_opt = shift;
     
-    print " $color{'green'}*$color{'normal'} indexed $color{'bold'}$num_man_pages$color{'normal'} man pages\n";
+    print " $color{'green'}*$color{'normal'} indexed $color{'bold'}$num_man_pages$color{'normal'} man pages:\n";
+    print " \tman pages: $color{'bold'}$true_man_pages $color{'normal'}\n";
+    print " \tduplicated man pages: $color{'bold'}$duplicate $color{'normal'}\n";
+    print " \tlink to man pages: $color{'bold'}$link $color{'normal'}\n";
+    print " \tempty man pages man pages: $color{'bold'}$empty $color{'normal'}\n";    
 
     _print_stat_with_occurrence( $index_file ) if ( $occurrence_get_opt);
     _print_stat_without_occurrence( $index_file ) unless ( $occurrence_get_opt);
@@ -269,8 +277,9 @@ sub stat_man_page_to_analize {
     my @statistics = ();
 
     foreach my $man_page_dir ( @$ref_manpath_dir ) {
+	next if ( -l $man_page_dir );
 
-	my @man_page_section = `ls $man_page_dir | grep man`;
+	my @man_page_section = `ls $man_page_dir 2>/dev/null | grep man`;
 	foreach my $section ( @man_page_section ) {
 
 	    my $current_dir = undef;
@@ -279,9 +288,9 @@ sub stat_man_page_to_analize {
 	    chop($section);
 	    $current_dir = $man_page_dir."/".$section;
 	    $current_dir = $dir_get_opt if ( $dir_get_opt );
-	    $num_man_page += `ls -1 $current_dir | wc -l`;
-	    
-	    @man_page_to_examine = `ls -1 $current_dir`;
+	    next if ( -l $current_dir );
+
+	    @man_page_to_examine = `ls -1 $current_dir 2>/dev/null`;
 	    if ( @$ref_file_get_opt ) {
 		
 		my @tmp;
@@ -306,6 +315,7 @@ sub stat_man_page_to_analize {
 		
 		$st = stat( $current_dir."/".$current_man_page ) or die "$current_dir/$current_man_page";
 		$size_total += ($st->size);
+		$num_man_page ++;
 	    }
 	    last if ( @$ref_file_get_opt );
 	    
@@ -354,13 +364,20 @@ sub _remove_dup {
 #execute manpath command and return an array of dir
 sub get_man_page_dir {
     my $tmp_dir = `manpath 2>/dev/null`;
+    my $tmp_dir2 = `echo \$MANPATH`;
+
+    chop($tmp_dir);
+    chop($tmp_dir2);
+
+    $tmp_dir = join( ':', $tmp_dir, $tmp_dir2 );
 
     $tmp_dir =~ s/:{2,}/:/g;
-    chop($tmp_dir);
 
     my @dir = split( /:/, $tmp_dir );
     my @dir_unique = &_remove_dup( \@dir );
 
+    @dir = ();
+
     return @dir_unique;
 }
 
