@@ -147,7 +147,7 @@ sub indexing_of_man_page_with_occurrence {
     &clean_man_page( $ref_man_page );
 
     # split text into single word
-    %man_page_text = &_split_man_page_into_words_with_occurence( $ref_man_page );
+    %man_page_text = &_split_man_page_into_words_with_list_occurence( $ref_man_page );
 
     # filter word with stoplist
     &_filter_with_stop_list( \%man_page_text, \%stop_list );
@@ -177,7 +177,7 @@ sub indexing_of_man_page_without_occurrence {
     &clean_man_page( $ref_man_page );
 
     # split text into single word
-    $ref_man_page_text = &_split_man_page_into_words_without_occurence( $ref_man_page );
+    $ref_man_page_text = &_split_man_page_into_words_without_list_occurence( $ref_man_page );
 
     # filter word with stoplist
     &_filter_with_stop_list( $ref_man_page_text, \%stop_list );
@@ -352,7 +352,7 @@ sub _add_man_page_title_to_dictionary_with_occurrence {
 
 ##    Split text into word
 ##
-sub _split_man_page_into_words_with_occurence {
+sub _split_man_page_into_words_with_list_occurence {
 
     my $ref_man_page = shift;
     
@@ -377,7 +377,7 @@ sub _split_man_page_into_words_with_occurence {
     return %word_man_page;
 }
 
-sub _split_man_page_into_words_without_occurence {
+sub _split_man_page_into_words_without_list_occurence {
 
     my $ref_man_page = shift;
     
